
.. _creation:

Numina Pipeline Creation Guide
##############################

This guide is intended as an introductory overview of pipeline creation with
Numina. For detailed reference documentation of the functions and classes
contained in the package, see the :ref:`reference`.

.. warning::

   This "Pipeline Creation Guide" is still a work in progress; some of the
   material is not organized, and several aspects of Numina are not covered
   in sufficient detail yet.

.. toctree::

   concepts
   example
   datatypes
